@@ -3,11 +3,13 @@ import numpy as np
 import os
 import datetime
 import traceback
+import json
+import requests
 from requests import Session
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util import Retry
 from ...api.raw import RawDataApi
-from ...view.raw_models import YahooIndexPrice
+from ...view.raw_models import YahooIndexPrice, EmBTCFromWeb
 from .raw_data_helper import RawDataHelper
 
 
@@ -212,6 +214,29 @@ class WebRawDataDownloader(object):
             traceback.print_exc()
             return False
 
+    def sina_btc_download(self):
+        try:
+            url = 'https://stock2.finance.sina.com.cn/futures/api/jsonp.php/var%20pp=/GlobalFuturesService.getGlobalFuturesDailyKLine?symbol=BTC'
+            response = requests.get(url)
+            dic = response._content.decode('utf8').replace('/*<script>location.href=\'//sina.com\';</script>*/\nvar pp=(','')[:-2]
+            data = json.loads(dic)
+            data = pd.DataFrame(data)
+            data = data[['date','close']].copy()
+            data.loc[:,'codes'] = 'cme_btc_cfd'
+            td = pd.to_datetime(data.date)
+            td = [i.date() for i in td]
+            data.date = td
+            raw = RawDataApi()
+            df_existed = raw.get_btc(['cme_btc_cfd'])
+            data = data[~data.date.isin(df_existed.date.tolist())]
+            self._data_helper._upload_raw(data, EmBTCFromWeb.__table__.name)
+            return True
+            
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            return False
+
     def download_all(self, start_date, end_date):
         failed_tasks = []
         if not self.cm_index_price(start_date, end_date):
@@ -223,6 +248,9 @@ class WebRawDataDownloader(object):
         if not self.yahoo_index_price(start_date, end_date):
             failed_tasks.append('yahoo_index_price')
 
+        if not self.sina_btc_download():
+            failed_tasks.append('sina_btc_close')
+
         return failed_tasks
 
 
