@@ -12,7 +12,7 @@ import pandas as pd
 
 from sqlalchemy.orm import sessionmaker
 
-from ...util.singleton import Singleton
+# from ...util.singleton import Singleton
 from ...util.wechat_bot import WechatBot
 from ...util.calculator import Calculator
 from ...util.aip_calc import xirr
@@ -25,7 +25,7 @@ from ..wrapper.mysql import BasicDatabaseConnector, DerivedDatabaseConnector
 from ..nav_reader.hedge_fund_nav_reader import HedgeFundNAVReader
 
 
-class FOFDataManagerLite(metaclass=Singleton):
+class FOFDataManagerLite():
 
     _DAYS_PER_YEAR_FOR_INTEREST = 360
 
@@ -189,7 +189,7 @@ class FOFDataManagerLite(metaclass=Singleton):
         if debug_mode:
             print(f'fof info: (manager_id){manager_id} (fof_id){fof_id} (management_fee){self._MANAGEMENT_FEE_PER_YEAR} (custodian_fee){self._CUSTODIAN_FEE_PER_YEAR} '
                   f'(admin_service_fee){self._ADMIN_SERVICE_FEE_PER_YEAR} (current_deposit_rate){self._DEPOSIT_INTEREST_PER_YEAR} (subscription_fee){self._SUBSCRIPTION_FEE} '
-                  f'(incentive fee mode){self._INCENTIVE_FEE_MODE}')
+                  f'(incentive_fee_mode){self._INCENTIVE_FEE_MODE} (established_date){self._ESTABLISHED_DATE})')
 
         # 获取FOF份额变化信息
         fof_scale = DerivedDataApi().get_hedge_fund_investor_pur_redemp(manager_id, [fof_id])
@@ -320,6 +320,7 @@ class FOFDataManagerLite(metaclass=Singleton):
         administrative_fee_list = pd.Series(dtype='float64', name='administrative_fee')
         deposit_interest_list = pd.Series(dtype='float64', name='interest')
         positions_list = pd.Series(dtype='float64', name='position')
+        errors_to_be_fixed_list = pd.Series(dtype='float64', name='errors')
         investor_pos_list = []
         for date in self._date_list:
             total_amount = 0
@@ -331,9 +332,11 @@ class FOFDataManagerLite(metaclass=Singleton):
                 pass
             else:
                 # 后边都是汇总信息了 所以在这里先加一下记录
-                investor_pos_list.append(scale_data.loc[:, ['fof_id', 'investor_id', 'purchase_amount', 'share_changed', 'event_type']].rename(columns={'purchase_amount': 'amount'}))
+                to_append_to_investor_pos = scale_data.loc[:, ['fof_id', 'investor_id', 'purchase_amount', 'raising_interest', 'share_changed', 'event_type']]
+                to_append_to_investor_pos['purchase_amount'] = to_append_to_investor_pos.purchase_amount.add(to_append_to_investor_pos.raising_interest, fill_value=0)
+                investor_pos_list.append(to_append_to_investor_pos.rename(columns={'purchase_amount': 'amount'}))
 
-                purchase_sum = scale_data.purchase_amount.sum()
+                purchase_sum = scale_data.purchase_amount.sum() + scale_data.raising_interest.sum()
                 share_sum = scale_data.share_changed.sum()
                 assert not pd.isnull(purchase_sum), '!!!'
                 total_amount += purchase_sum
@@ -439,7 +442,10 @@ class FOFDataManagerLite(metaclass=Singleton):
                 misc_fees = 0
 
             # 应收银行存款利息
-            deposit_interest = round(other_assets_list.iat[-1] * self._DEPOSIT_INTEREST_PER_YEAR / self._DAYS_PER_YEAR_FOR_INTEREST, 2)
+            if other_assets_list.empty:
+                deposit_interest = 0
+            else:
+                deposit_interest = round(other_assets_list.iat[-1] * self._DEPOSIT_INTEREST_PER_YEAR / self._DAYS_PER_YEAR_FOR_INTEREST, 2)
             deposit_interest_list.loc[date] = deposit_interest
 
             other_assets += (deposit_interest - misc_fees)
@@ -492,14 +498,17 @@ class FOFDataManagerLite(metaclass=Singleton):
                 position = pd.concat([fund_pos_info, hedge_pos_info], axis=0).rename_axis(index='fund_id').reset_index()
                 position = position[position.share != 0]
                 position['mv'] = position.share * position.nav
-                positions_list.loc[date] = json.dumps(position.to_dict(orient='records'))
+            else:
+                position = pd.Series().to_frame()
+            positions_list.loc[date] = json.dumps(position.to_dict(orient='records'))
 
             # 计算修正净资产
             try:
                 errors_to_be_fixed = round(self._manually.at[date, 'amount'], 2)
+                errors_to_be_fixed_list.loc[date] = errors_to_be_fixed
             except KeyError:
                 errors_to_be_fixed = 0
-            today_net_assets_fixed = today_net_assets + errors_to_be_fixed
+            today_net_assets_fixed = today_net_assets + errors_to_be_fixed_list.sum()
             net_assets_fixed_list.loc[date] = today_net_assets_fixed
 
             # 如果今日有投资人申购fof 记录下来
@@ -639,7 +648,7 @@ class FOFDataManagerLite(metaclass=Singleton):
         else:
             print('[dump_fof_nav_and_pos_to_db] no position, should calc it first')
 
-        if self._fof_position_details is not None:
+        if self._fof_position_details is not None and not self._fof_position_details.empty:
             now_df = DerivedDataApi().get_fof_position_detail(manager_id, [fof_id])
             if now_df is not None:
                 now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted']).astype(self._fof_position_details.dtypes.to_dict())
@@ -695,7 +704,7 @@ class FOFDataManagerLite(metaclass=Singleton):
         else:
             print('[dump_fof_nav_and_pos_to_db] get investor position failed')
 
-        investor_summary_df = FOFDataManagerLite().get_investor_pos_summary(manager_id, fof_id)
+        investor_summary_df = FOFDataManagerLite().get_investor_pos_summary(manager_id)
         if investor_summary_df is not None:
             now_df = FOFDataManagerLite().get_fof_investor_position_summary(manager_id)
             if now_df is not None:
@@ -997,16 +1006,16 @@ class FOFDataManagerLite(metaclass=Singleton):
         return df.sort_values(by=['fund_id', 'datetime', 'insert_time']).drop_duplicates(subset=['fund_id', 'datetime'], keep='last')
 
     @staticmethod
-    def get_investor_pos_summary(manager_id: str, fof_id: str):
-        fof_nav = DerivedDataApi().get_fof_nav_calc(manager_id, [fof_id])
-        if fof_nav is None:
+    def get_investor_pos_summary(manager_id: str):
+        fof_nav = DerivedDataApi().get_fof_nav(manager_id)
+        if fof_nav is None or fof_nav.empty:
             return
-        if fof_nav.empty:
-            return
-        fof_nav = fof_nav.pivot(index='datetime', columns='fof_id', values='nav')
-        fof_scale_info = DerivedDataApi().get_hedge_fund_investor_pur_redemp(manager_id, [fof_id])
+        fof_scale_info = DerivedDataApi().get_hedge_fund_investor_pur_redemp(manager_id)
         if fof_scale_info is None:
             return
+        fof_nav = fof_nav[fof_nav.fof_id.isin(fof_scale_info.fof_id.unique())]
+        fof_nav = fof_nav.pivot(index='datetime', columns='fof_id', values='nav')
+        fof_nav = fof_nav.reindex(fof_nav.index.union(fof_scale_info.datetime.unique())).rename_axis(index='datetime').sort_index().ffill()
 
         investor_pos = {}
         for row in fof_scale_info.itertuples(index=False):
@@ -1025,6 +1034,9 @@ class FOFDataManagerLite(metaclass=Singleton):
                 pos['left_share'].loc[pos['left_share'].index >= row.datetime, row.fof_id] += row.share_changed
                 pos['amount'].loc[pos['amount'].index >= row.datetime, row.fof_id] += row.purchase_amount
                 pos['left_amount'].loc[pos['left_amount'].index >= row.datetime, row.fof_id] += row.purchase_amount
+                if row.event_type == FOFTradeStatus.PURCHASE:
+                    pos['amount'].loc[pos['amount'].index >= row.datetime, row.fof_id] += row.raising_interest
+                    pos['left_amount'].loc[pos['left_amount'].index >= row.datetime, row.fof_id] += row.raising_interest
             elif row.event_type in (FOFTradeStatus.REDEEM, ):
                 assert not pd.isnull(row.share_changed), '!!!'
                 pos['left_share'].loc[pos['left_share'].index >= row.datetime, row.fof_id] += row.share_changed
@@ -1082,7 +1094,10 @@ class FOFDataManagerLite(metaclass=Singleton):
                     init_mv = fof_nav.at[actual_start_date, 'nav'] * row.share_changed
                 except KeyError:
                     init_mv = row.share_changed
-                investor_mvs[row.investor_id].append({'trade_ids': [row.id], 'start_date': actual_start_date, 'amount': row.purchase_amount, 'left_amount': row.purchase_amount, 'share': row.share_changed, 'left_share': row.share_changed, 'init_mv': init_mv, 'water_line': row.acc_unit_value})
+                the_amount = row.purchase_amount
+                if row.event_type == FOFTradeStatus.PURCHASE:
+                    the_amount += row.raising_interest
+                investor_mvs[row.investor_id].append({'trade_ids': [row.id], 'start_date': actual_start_date, 'amount': the_amount, 'left_amount': the_amount, 'share': row.share_changed, 'left_share': row.share_changed, 'init_mv': init_mv, 'water_line': row.acc_unit_value})
             elif row.event_type in (FOFTradeStatus.REDEEM, ):
                 share_redemp = row.share_changed
                 for one in investor_mvs[row.investor_id]:
@@ -1132,7 +1147,7 @@ class FOFDataManagerLite(metaclass=Singleton):
         fof_info: Optional[pd.DataFrame] = FOFDataManagerLite.get_fof_info(manager_id, [fof_id])
         if fof_info is None:
             return
-        fof_nav = DerivedDataApi().get_fof_nav_calc(manager_id, [fof_id])
+        fof_nav = DerivedDataApi().get_fof_nav(manager_id, [fof_id])
         if fof_nav is None:
             return
         try:
