@@ -525,7 +525,6 @@ class HedgeFundDataManager(metaclass=Singleton):
             dividends_receivable = df.at['1203', '市值.1']
         except KeyError:
             dividends_receivable = np.nan
-        other_assets = interest_receivable + deposit_in_bank
         payable_to_managers = df.at['2206', '市值.1']
         payable_to_custodian = df.at['2207', '市值.1']
         payable_to_admin_service = 0
@@ -536,13 +535,11 @@ class HedgeFundDataManager(metaclass=Singleton):
                 got_the_item = True
             except KeyError:
                 pass
+        other_assets = deposit_in_bank + interest_receivable + (pur_amt_receivable if not pd.isnull(pur_amt_receivable) else 0) + (sec_clearing_fund if not pd.isnull(sec_clearing_fund) else 0) + (dividends_receivable if not pd.isnull(dividends_receivable) else 0) - (payable_to_managers + payable_to_custodian + payable_to_admin_service)
         if not got_the_item:
             payable_to_admin_service = np.nan
 
         nav = float(df.loc['今日单位净值', '科目名称'])
-        pur_amt_receivable = np.nan
-        sec_clearing_fund = np.nan
-
         total_df = pd.Series({
             'fof_id': fof_id,
             'manager_id': manager_id,
