@@ -3,7 +3,7 @@
 from typing import Optional, List
 # import datetime
 import os
-# import traceback
+import traceback
 import time
 import tarfile
 
@@ -14,7 +14,7 @@ from ...util.wechat_bot import WechatBot
 from ..wrapper.mysql import RawDatabaseConnector
 from ..api.raw import RawDataApi
 from ..api.basic import BasicDataApi
-from ..view.raw_models import HFIndexPrice
+from ..view.raw_models import HFIndexPrice, HFFundNav
 
 
 class ResearchNAVReader:
@@ -36,18 +36,46 @@ class ResearchNAVReader:
         for one in tar:
             if not one.name.endswith('.xls') and not one.name.endswith('.xlsx'):
                 continue
-            if '融智' not in one.name:
-                return
-            print(f'[_read_for_NAVData] (name in tar){one.name}')
-            p_name = one.split('/')[-1].split('.')[0]
-            key_name = file_path.split('融智-')[-1].split('.')[0]
-            df = pd.read_excel(tar.extractfile(one), header=3, na_values=['--'])
-            df = df.rename(columns={'指数日期': 'index_date', '指数计算日期': 'calcu_date', key_name: 'close'})
-            df = df[['index_date', 'calcu_date', 'close']]
-            asset_info = BasicDataApi().get_asset_info_by_type(['策略指数'])
-            df['index_id'] = asset_info[asset_info.real_name == p_name].real_id.array[0]
-            df['index_date'] = pd.to_datetime(df.index_date, infer_datetime_format=True).dt.date
-            df['calcu_date'] = pd.to_datetime(df.calcu_date, infer_datetime_format=True).dt.date
+            if '业绩走势' in one.name:
+                continue
+            try:
+                try:
+                    print(f'[_read_for_NAVData] (name in tar){one.name}')
+                except UnicodeEncodeError:
+                    replace_dict = {
+                        '\udc9bK': '汯',
+                        '\udcacB': '珺',
+                        '\udcd4Z': '訸',
+                        '\udcb6G': '禛',
+                    }
+                    p_name = one.name
+                    for k, v in replace_dict.items():
+                        p_name = p_name.replace(k, v)
+                    print(f'[_read_for_NAVData] (name in tar (fixed)){p_name}')
+                else:
+                    p_name = one.name
+                p_name = p_name.split('.')[0]
+                df = pd.read_excel(tar.extractfile(one), na_values=['--'])
+                df = df.rename(columns={'日期': 'datetime', '净值(分红再投)': 'nav'})
+                df = df[['datetime', 'nav']]
+                hf_fund_info = RawDataApi().get_hf_fund_info()
+                hf_fund_info = hf_fund_info[hf_fund_info.desc_name == p_name]
+                fund_id = hf_fund_info.fund_id.array[0]
+                df['fund_id'] = fund_id
+                df['datetime'] = pd.to_datetime(df.datetime, infer_datetime_format=True).dt.date
+                hf_fund_nav = RawDataApi().get_hf_fund_nav(fund_ids=[fund_id])
+                if hf_fund_nav is not None:
+                    df = df.astype(hf_fund_nav.dtypes.to_dict())
+                    # merge on all columns
+                    df = df.merge(hf_fund_nav, how='left', indicator=True, validate='one_to_one')
+                    df = df[df._merge == 'left_only'].drop(columns=['_merge'])
+                print(df)
+                # TODO: 最好原子提交下边两步
+                RawDataApi().delete_hf_fund_nav(fund_id_to_delete=fund_id, datetime_list=df.datetime.to_list())
+                # 更新到db
+                df.to_sql(HFFundNav.__table__.name, RawDatabaseConnector().get_engine(), index=False, if_exists='append')
+            except Exception:
+                traceback.print_exc()
         tar.close()
 
     @staticmethod
@@ -97,7 +125,7 @@ class ResearchNAVReader:
 
     def _notify_error_event(self, err_msg: str):
         print(f'[read_navs_and_dump_to_db] {err_msg}')
-        self._wechat_bot.send_hedge_fund_nav_update_failed(err_msg)
+        # self._wechat_bot.send_hedge_fund_nav_update_failed(err_msg)
 
     def read_navs_and_dump_to_db(self):
         try:
@@ -130,6 +158,7 @@ class ResearchNAVReader:
                 else:
                     raise NotImplementedError('unknown research nav file from attachment')
             except Exception as e:
+                traceback.print_exc()
                 self._notify_error_event(f'{e} (parse) (name){name} (file_path){file_path}')
                 continue
 
