@@ -1108,10 +1108,10 @@ class Calculator:
             df = index_val.join(index_price).ffill().dropna()
             _df = Calculator.get_index_pct_data(dates=df.index,
                                                 values=df[valuation_type].values,
-                                                pct_list=[0.3,0.5,0.7],
+                                                pct_list=[0.1,0.5,0.9],
                                                 windows=df.shape[0],
                                                 min_periods=60)
-            _df.columns = ['30分位','50分位','70分位']
+            _df.columns = ['10分位','50分位','90分位']
             df = df.join(_df)
             #df.loc[:,'中位数'] = df[valuation_type].rolling(window=df.shape[0], min_periods=10).median()
             #df.loc[:,'百分位'] = df[valuation_type].rolling(window=df.shape[0], min_periods=10).apply(pctrank)
@@ -1210,15 +1210,21 @@ class Calculator:
     def get_product_rolling_corr(fund_navs, windows=20, period='周度', index_id='hs300'):
         try:
             basic = BasicDataApi()
-            index_name = basic.get_index_info([index_id]).desc_name.tolist()[0]
+            try:
+                index_name = basic.get_index_info([index_id]).desc_name.tolist()[0]
+            except:
+                index_name = ''
             if index_name in fund_navs:
                 pass
             else:
-                index_price = basic.get_index_price([index_id]).pivot_table(index='datetime',columns='index_id',values='close')
-                index_price.columns = [index_name]
-                index_price = index_price.reindex(fund_navs.index.union(index_price.index)).ffill()
-                fund_navs = fund_navs.join(index_price).sort_index()
-            
+                try:
+                    index_price = basic.get_index_price([index_id]).pivot_table(index='datetime',columns='index_id',values='close')
+                    index_price.columns = [index_name]
+                    index_price = index_price.reindex(fund_navs.index.union(index_price.index)).ffill()
+                    fund_navs = fund_navs.join(index_price).sort_index()
+                except:
+                    pass
+
             result = Calculator.get_rolling_corr(fund_navs, windows, period)
             if result.empty:
                 return {
